@@ -10,7 +10,7 @@ import json
 
 import requests
 
-from zabbix_feishu_alert.message_base import FeishuBase
+from .message_base import FeishuBase
 
 
 
@@ -37,11 +37,11 @@ if __name__ == '__main__':
                            'cli_9e44d8e26dbb500d',
                            '8X4jX9MLwg6AXIEVJh0lC8oeHNDBfbnd')
 
-    feishu.send_alarm_message(feishu.user_id,
-                              feishu.chat_id,
-                              feishu.tenant_access_token,
-                              feishu.image_key,
-                              "Zabbix Alert Title",
+    feishu.send_alarm_message("Zabbix Alert Title",
                               "Zabbix Alert Content",
                               38524,
-                              '10.102.0.11')
+                              'http://10.102.0.11:8000/monitor/problem_ack/')
+
+    feishu.send_recovery_message("Zabbix Recovery Title", "Zabbix Recovery Title")
+
+    feishu.send_ack_message("Zabbix Ack Title", "Zabbix Ack Title")
